@@ -31,46 +31,47 @@ INVENIO_CONFIG_TUGRAZ_IP_RANGES =
 # ===========
 # See https://invenio-app.readthedocs.io/en/latest/configuration.html
 
-APP_ALLOWED_HOSTS = ['0.0.0.0',
-                     'localhost',
-                     '127.0.0.1',
-                     'invenio-dev01.tugraz.at',
-                     'invenio-test.tugraz.at'
-                     ]
+APP_ALLOWED_HOSTS = [
+    "0.0.0.0",
+    "localhost",
+    "127.0.0.1",
+    "invenio-dev01.tugraz.at",
+    "invenio-test.tugraz.at",
+]
 """Allowed Hosts"""
 
 APP_DEFAULT_SECURE_HEADERS = {
-    'content_security_policy': {
-        'default-src': [
+    "content_security_policy": {
+        "default-src": [
             "'self'",
-            'fonts.googleapis.com',
-            '*.gstatic.com',
-            'data:',
+            "fonts.googleapis.com",
+            "*.gstatic.com",
+            "data:",
             "'unsafe-inline'",
             "'unsafe-eval'",
             "blob:",
         ],
     },
-    'content_security_policy_report_only': False,
-    'content_security_policy_report_uri': None,
-    'force_file_save': False,
-    'force_https': True,
-    'force_https_permanent': False,
-    'frame_options': 'sameorigin',
-    'frame_options_allow_from': None,
-    'session_cookie_http_only': True,
-    'session_cookie_secure': True,
-    'strict_transport_security': True,
-    'strict_transport_security_include_subdomains': True,
-    'strict_transport_security_max_age': 31556926,  # One year in seconds
-    'strict_transport_security_preload': False,
+    "content_security_policy_report_only": False,
+    "content_security_policy_report_uri": None,
+    "force_file_save": False,
+    "force_https": True,
+    "force_https_permanent": False,
+    "frame_options": "sameorigin",
+    "frame_options_allow_from": None,
+    "session_cookie_http_only": True,
+    "session_cookie_secure": True,
+    "strict_transport_security": True,
+    "strict_transport_security_include_subdomains": True,
+    "strict_transport_security_max_age": 31556926,  # One year in seconds
+    "strict_transport_security_preload": False,
 }
 
 # Invenio-Mail
 # ===========
 # See https://invenio-mail.readthedocs.io/en/latest/configuration.html
 
-MAIL_SERVER = 'localhost'
+MAIL_SERVER = "localhost"
 """Domain ip where mail server is running."""
 
 SECURITY_EMAIL_SENDER = "info@invenio-test.tugraz.at"
@@ -117,23 +118,23 @@ when register.
 SSO_SAML_IDPS = {}
 """Configuration of IDPS. Actual values can be find in to invenio.cfg file"""
 
-SSO_SAML_DEFAULT_BLUEPRINT_PREFIX = '/shibboleth'
+SSO_SAML_DEFAULT_BLUEPRINT_PREFIX = "/shibboleth"
 """Base URL for the extensions endpoint."""
 
-SSO_SAML_DEFAULT_METADATA_ROUTE = '/metadata/<idp>'
+SSO_SAML_DEFAULT_METADATA_ROUTE = "/metadata/<idp>"
 """URL route for the metadata request."""
 """This is also SP entityID https://domain/shibboleth/metadata/<idp>"""
 
-SSO_SAML_DEFAULT_SSO_ROUTE = '/login/<idp>'
+SSO_SAML_DEFAULT_SSO_ROUTE = "/login/<idp>"
 """URL route for the SP login."""
 
-SSO_SAML_DEFAULT_ACS_ROUTE = '/authorized/<idp>'
+SSO_SAML_DEFAULT_ACS_ROUTE = "/authorized/<idp>"
 """URL route to handle the IdP login request."""
 
-SSO_SAML_DEFAULT_SLO_ROUTE = '/slo/<idp>'
+SSO_SAML_DEFAULT_SLO_ROUTE = "/slo/<idp>"
 """URL route for the SP logout."""
 
-SSO_SAML_DEFAULT_SLS_ROUTE = '/sls/<idp>'
+SSO_SAML_DEFAULT_SLS_ROUTE = "/sls/<idp>"
 """URL route to handle the IdP logout request."""
 
 # Invenio-accounts
